2023-02-12 Version: 1.0.4
- CreateScalingGroup and DescribeScalingGroup support NLB server group and new open api AttachServerGroups and DetachServerGroups .

2023-01-13 Version: 1.0.3
- CreateScalingGroup and DescribeScalingGroup support resourcegroup.

2022-10-14 Version: 1.0.2
- Support user custom removal  function policy.

2022-10-14 Version: 1.0.1
- LifecycleHook support disable and enable, ScaleWithAdjustment support scale by instance type.

2022-09-09 Version: 1.0.0
- Ess Tea 2022 SDK release.

